@@ -2,9 +2,6 @@
 # -*-coding:utf8-*-
 # 注意demo无法直接运行，需要pip安装sdk后才能运行
 # 使能机械臂
-from typing import (
-    Optional,
-)
 import time
 from piper_sdk import *
 
@@ -13,6 +10,6 @@ if __name__ == "__main__":
     piper = C_PiperInterface_V2()
     piper.ConnectPort()
     while(piper.DisablePiper()):
-        pass
         time.sleep(0.01)
     print("失能成功!!!!")
+    
\ No newline at end of file
