@@ -1,9 +1,6 @@
 #!/usr/bin/env python3
 # -*-coding:utf8-*-
 # 注意demo无法直接运行，需要pip安装sdk后才能运行
-from typing import (
-    Optional,
-)
 import time
 from piper_sdk import *
 
@@ -18,19 +15,18 @@ if __name__ == "__main__":
     count = 0
     while True:
         print(piper.GetArmGripperMsgs())
-        import time
         count  = count + 1
         if(count == 0):
             print("1-----------")
             range = 0
         elif(count == 300):
             print("2-----------")
-            range = 50 * 1000 # 50mm
+            range = 0.05 * 1000 * 1000 # 0.05m = 50mm
         elif(count == 600):
             print("3-----------")
             range = 0
             count = 0
+        range = round(range)
         piper.GripperCtrl(abs(range), 1000, 0x01, 0)
-        
         time.sleep(0.005)
-        pass
\ No newline at end of file
+    
\ No newline at end of file
