@@ -1,9 +1,6 @@
 #!/usr/bin/env python3
 # -*-coding:utf8-*-
 # 注意demo无法直接运行，需要pip安装sdk后才能运行
-from typing import (
-    Optional,
-)
 import time
 from piper_sdk import *
 
@@ -17,7 +14,6 @@ if __name__ == "__main__":
     position = [0,0,0,0,0,0,0]
     count = 0
     while True:
-        import time
         count  = count + 1
         # print(count)
         if(count == 0):
@@ -44,4 +40,4 @@ if __name__ == "__main__":
         print(piper.GetArmStatus())
         print(position)
         time.sleep(0.005)
-        pass
\ No newline at end of file
+    
\ No newline at end of file
