@@ -3,10 +3,6 @@
 # 注意demo无法直接运行，需要pip安装sdk后才能运行
 # piper机械臂圆弧模式demo
 # 注意机械臂工作空间内不要有障碍
-
-from typing import (
-    Optional,
-)
 import time
 from piper_sdk import *
 
@@ -16,6 +12,8 @@ if __name__ == "__main__":
     while( not piper.EnablePiper()):
         time.sleep(0.01)
     piper.GripperCtrl(0,1000,0x01, 0)
+    # 切换至MOVEC模式
+    piper.MotionCtrl_2(0x01, 0x03, 30, 0x00)
     # X:135.481
     piper.EndPoseCtrl(135481,9349,161129,178756,6035,-178440)
     piper.MoveCAxisUpdateCtrl(0x01)
@@ -27,4 +25,4 @@ if __name__ == "__main__":
     piper.MoveCAxisUpdateCtrl(0x03)
     time.sleep(0.001)
     piper.MotionCtrl_2(0x01, 0x03, 30, 0x00)
-    pass
\ No newline at end of file
+    
\ No newline at end of file
