@@ -2,11 +2,6 @@
 # -*-coding:utf8-*-
 # 注意demo无法直接运行，需要pip安装sdk后才能运行
 # 设置机械臂重置，需要在mit或者示教模式切换为位置速度控制模式时执行
-
-from typing import (
-    Optional,
-)
-import time
 from piper_sdk import *
 
 # 测试代码
@@ -14,4 +9,4 @@ if __name__ == "__main__":
     piper = C_PiperInterface_V2()
     piper.ConnectPort()
     piper.MotionCtrl_1(0x02,0,0)#恢复
-    piper.MotionCtrl_2(0, 0, 0, 0x00)#位置速度模式
+    
\ No newline at end of file
