@@ -2,10 +2,6 @@
 # -*-coding:utf8-*-
 # 注意demo无法直接运行，需要pip安装sdk后才能运行
 # 读取机械臂的所有电机的最大加速度限制
-
-from typing import (
-    Optional,
-)
 import time
 from piper_sdk import *
 
@@ -16,4 +12,5 @@ if __name__ == "__main__":
     while True:
         piper.SearchAllMotorMaxAccLimit()
         print(piper.GetAllMotorMaxAccLimit())
-        time.sleep(0.01)
\ No newline at end of file
+        time.sleep(0.01)
+    
\ No newline at end of file
