@@ -1,10 +1,6 @@
 #!/usr/bin/env python3
 # -*-coding:utf8-*-
 # 注意demo无法直接运行，需要pip安装sdk后才能运行
-
-from typing import (
-    Optional,
-)
 import time
 from piper_sdk import *
 
@@ -14,4 +10,5 @@ if __name__ == "__main__":
     piper.ConnectPort()
     while True:
         print(piper.GetArmEndPoseMsgs())
-        time.sleep(0.01)
\ No newline at end of file
+        time.sleep(0.01)
+    
\ No newline at end of file
