@@ -1,9 +1,5 @@
 #!/usr/bin/env python3
 # -*-coding:utf8-*-
-
-from typing import (
-    Optional,
-)
 import time
 from piper_sdk import *
 
@@ -18,4 +14,5 @@ if __name__ == "__main__":
         # 反馈6个浮点数的列表，表示 1-6 号关节的位姿，-1表示joint6的位姿
         print(f"feedback:{piper.GetFK('feedback')[-1]}")
         print(f"control:{piper.GetFK('control')}")
-        time.sleep(0.01)
\ No newline at end of file
+        time.sleep(0.01)
+    
\ No newline at end of file
