@@ -2,9 +2,7 @@
 # -*-coding:utf8-*-
 # 注意demo无法直接运行，需要pip安装sdk后才能运行
 # 读取机械臂消息并打印,需要先安装piper_sdk
-from typing import (
-    Optional,
-)
+import time
 from piper_sdk import *
 
 # 测试代码
@@ -12,7 +10,6 @@ if __name__ == "__main__":
     piper = C_PiperInterface_V2()
     piper.ConnectPort()
     while True:
-        import time
         print(piper.GetArmLowSpdInfoMsgs())
         time.sleep(0.005)
-        pass
+    
\ No newline at end of file
