@@ -4,10 +4,6 @@
 # V2版本sdk
 # 单独设定某个电机的最大加速度
 # 注意这个指令是通过协议直接写入到驱动flash中，不可实时更新
-
-from typing import (
-    Optional,
-)
 import time
 from piper_sdk import *
 
@@ -25,4 +21,5 @@ if __name__ == "__main__":
     while True:
         piper.SearchAllMotorMaxAccLimit()
         print(piper.GetAllMotorMaxAccLimit())
-        time.sleep(0.1)
\ No newline at end of file
+        time.sleep(0.1)
+    
\ No newline at end of file
