@@ -1,7 +1,6 @@
-from ..piper_protocol_base import C_PiperParserBase
+# -*- coding: utf-8 -*-
 from .piper_protocol_v2 import C_PiperParserV2
 
 __all__ = [
-    "C_PiperParserBase",
     "C_PiperParserV2"
 ]
